@@ -42,11 +42,11 @@ def _call_deb(conanfile, deb_id, hook_manager, conanfile_path, ref, copy_info):
     #                      reference=ref, deb_id=deb_id)
 
     output.highlight("Calling deb()")
-    folders = [conanfile.source_folder, conanfile.build_folder] \
-        if conanfile.source_folder != conanfile.build_folder else [conanfile.build_folder]
+    folders = [conanfile.source_folder, conanfile.package_folder] \
+        if conanfile.source_folder != conanfile.package_folder else [conanfile.package_folder]
     conanfile.copy = FileCopier(folders, conanfile.deb_folder)
     with conanfile_exception_formatter(str(conanfile), "deb"):
-        with chdir(conanfile.build_folder):
+        with chdir(conanfile.package_folder):
             with conan_v2_property(conanfile, 'info',
                                    "'self.info' access in deb() method is deprecated"):
                 _create_deb_file(conanfile)
@@ -104,7 +104,7 @@ def _create_deb_file(conanfile):
         conanfile.run("rm " + changelog_file)
     add_changelog_cmd = "echo " + conanfile.changelog + " >> " + changelog_file
     conanfile.run(add_changelog_cmd)
-        
+    
     ## add control file
     control_file = debian_folder + "/control"
     if os.path.exists(control_file):
